#!/bin/bash 

#
#  Copyright (c) Members of the EGEE Collaboration. 2004.
#  See http://eu-egee.org/partners/ for details on the copyright holders.
#  For license conditions see the license file or http://eu-egee.org/license.html
# 
#  GLite Data Transfer Scripts
#
#  Authors: Paolo Badino <paolo.badino@cern.ch>
#  Maintained: Steve Traylen <steve.traylen@cern.ch>
#  Version info: $Id: transfer-monitor-gridview.sh,v 1.5 2007/07/03 11:42:17 straylen Exp $
#  Release: $Name: glite-data-transfer-monitor-gridview_R_1_0_3_1 $
#
#

usage="transfer-monitor-gridview [ -f <configfile> ] -m publish || -m summary -i <interval> ||  [ -h ] "

# Defaults for the configuration file.
GRIDVIEW_INSTALLDIR=/opt/glite
GRIDVIEW_OUTDIR=/opt/glite/var/transfer-monitor-gridview/www
ORACLE_LOCATION=/usr/lib/oracle/10.2.0.1
GLITE_SD_PLUGIN=bdii

# Read in and check the configuration.
CONFIG=/opt/glite/etc/transfer-monitor-gridview.conf

while getopts "f:m:hi:" options ; do
   case $options in 
      h) echo $usage
         exit ;;
      f) CONFIG=$OPTARG;;
      m) GRIDVIEW_METHOD=$OPTARG;;
      i) GRIDVIEW_INTERVAL=$OPTARG;;
      *) echo $usage
         exit 1;;
   esac
done

# Read in the configuration.
if [ ! -r $CONFIG ] ; then
    echo "Config file $CONFIG is not readable"
    exit 1;
else
    . $CONFIG
fi

# Import Common functions
# source $GLITE_LOCATION/share/glite-data-transfer-scripts/publishing/gridview/common.sh
source $GRIDVIEW_INSTALLDIR/libexec/transfer-monitor-gridview-common.sh

if [ "$GRIDVIEW_METHOD" = "summary" ] && [ "$GRIDVIEW_INTERVAL" != "hour" ] ; then
  echo "The Gridview interval must be hour" 
  echo $usage 
  exit -1;
fi

if [ $GRIDVIEW_METHOD = "publish" ] ; then
    # Publish data
    gridview_publishing
elif [ $GRIDVIEW_METHOD = "summary" ] ; then
    # Publish data
    gridview_summary_publishing
else
    echo "The gridview method $GRIDVIEW_METHOD is not acceptable."
    echo "The only method supported are the publish and summary"
    echo $usage
    exit 1;
fi



