#!/bin/bash 

#
#  Copyright (c) Members of the EGEE Collaboration. 2004.
#  See http://eu-egee.org/partners/ for details on the copyright holders.
#  For license conditions see the license file or http://eu-egee.org/license.html
# 
#  GLite Data Transfer Scripts
#
#  Authors: Paolo Badino <paolo.badino@cern.ch>
#  Maintained: Steve Traylen <steve.traylen@cern.ch>
#  Version info: $Id: transfer-monitor-gridview-common.sh,v 1.5 2007/07/03 11:42:17 straylen Exp $
#  Release: $Name: glite-data-transfer-monitor-gridview_R_1_0_3_1 $
#
#

###############################################################################
# Log finctions
###############################################################################

#
#  log_debug
#
function log_debug {
   if [ "x$DEBUG_ENABLED" != "x" ]; then
       echo "DEBUG: $1"
   fi 
}
#
#  log error and exit
#
function error {
   echo "ERROR: $1"
   exit 1
}

###############################################################################
# Set the Default Values
###############################################################################

# Python
if [ "x$PYTHON" == "x" ] ; then
    PYTHON=/usr/bin/python
fi

# Include Oracle lib in LD_LIBRARY_PATH
if [ "x$ORACLE_LOCATION" != "x" ] ; then
    # Check that the folder exists
    if [ -d $ORACLE_LOCATION/client/lib ] ; then 
        export LD_LIBRARY_PATH=$ORACLE_LOCATION/client/lib:$LD_LIBRARY_PATH
    else
        # check with ORACLE_LOCATION/lib
        if [ -d $ORACLE_LOCATION/lib ] ; then
            export LD_LIBRARY_PATH=$ORACLE_LOCATION/lib:$LD_LIBRARY_PATH
        else
            echo "neither $ORACLE_LOCATION/client/lib nor $ORACLE_LOCATION/lib exist";
            exit -1;
        fi
    fi
fi

# Print the configuration information
log_debug "GRIDVIEW_INSTALLDIR: $GRIDVIEW_INSTALLDIR";
log_debug "PYTHON:              $PYTHON";
log_debug "GRIDVIEW_OUTDIR:     $GRIDVIEW_OUTDIR";
log_debug "LD_LIBRARY_PATH:     $LD_LIBRARY_PATH";
log_debug "GLITE_SD_PLUGIN:     $GLITE_SD_PLUGIN" ;
log_debug "LCG_GFAL_INFOSYS:    $LCG_GFAL_INFOSYS" ;

export GLITE_SD_PLUGIN LCG_GFAL_INFOSYS


###############################################################################
# Functions
###############################################################################

#
# check preconditions
#
function check_preconditions {
    if [ "x$GRIDVIEW_OUTDIR" == "x" ]; then
        error "No Reports Output set"
    elif [ ! -w $GRIDVIEW_OUTDIR ] || [ ! -d $GRIDVIEW_OUTDIR ] ; then
        error "Directory $GRIDVIEW_OUTDIR can not be written to."
    fi
}

#
# Validation
#
function validate_environment {

    # Check Preconditions
    check_preconditions

    log_debug "Run Report Validation"

    # Run Report 
    log_debug "$PYTHON $GRIDVIEW_INSTALLDIR/libexec/transfer-monitor-gridview.py -u $DB_USER -p $DB_PASSWORD -c \"$DB_CONNECT_STR\" -Z"
    $PYTHON GRIDVIEW_INSTALLDIR/libexec/transfer-monitor-gridview.py -u $DB_USER -p $DB_PASSWORD -c "$DB_CONNECT_STR" -Z
    if [ $? -ne 0 ]; then
        error "Failed to run validation"
    fi

    log_debug "Validation Success"
}

#
# Publish data for gridview
#
function gridview_publishing {

    # Check Preconditions
    check_preconditions

    log_debug "Executing gridview publishing script"

    # Run Report 
    log_debug "$PYTHON $GRIDVIEW_INSTALLDIR/libexec/transfer-monitor-gridview.py -u $DB_USER -p $DB_PASSWORD -c \"$DB_CONNECT_STR\" -o \"$GRIDVIEW_OUTDIR/gridview.dat\""
    $PYTHON $GRIDVIEW_INSTALLDIR/libexec/transfer-monitor-gridview.py -u $DB_USER -p $DB_PASSWORD -c "$DB_CONNECT_STR" -o "$GRIDVIEW_OUTDIR/gridview.dat"
    if [ $? -ne 0 ]; then
        error "Failed to execute gridview publishing script" 
    fi

    log_debug "data published for gridview"
}

#
# Publish data for gridview summary
#
function gridview_summary_publishing {

    # Check Preconditions
    check_preconditions
   
    log_debug "Executing gridview summary publishing script"

    # Run Report 
    log_debug "$PYTHON $GRIDVIEW_INSTALLDIR/libexec/transfer-monitor-gridview.py -u $DB_USER -p $DB_PASSWORD -c \"$DB_CONNECT_STR\" -o \"$GRIDVIEW_OUTDIR/gridview-summary.dat\" -S $GRIDVIEW_INTERVAL"
    $PYTHON $GRIDVIEW_INSTALLDIR/libexec/transfer-monitor-gridview.py -u $DB_USER -p $DB_PASSWORD -c "$DB_CONNECT_STR" -o "$GRIDVIEW_OUTDIR/gridview-summary.dat" -S "$GRIDVIEW_INTERVAL"
    if [ $? -ne 0 ]; then
        error "Failed to execute gridview summary publishing script" 
    fi

    log_debug "summary published for gridview"
}

